import { __decorate } from "tslib";
import { rtfm } from '@twurple/common';
import { BaseApi } from "../BaseApi.mjs";
import { HelixContentClassificationLabel } from "./HelixContentClassificationLabel.mjs";
/**
 * The Helix API methods that deal with content classification labels.
 *
 * Can be accessed using `client.contentClassificationLabels` on an {@link ApiClient} instance.
 *
 * ## Example
 * ```ts
 * const api = new ApiClient({ authProvider });
 * const labels = await api.contentClassificationLabels.getAll();
 * ```
 *
 * @meta category helix
 * @meta categorizedTitle Content classification labels
 */
let HelixContentClassificationLabelApi = class HelixContentClassificationLabelApi extends BaseApi {
    /**
     * Fetches a list of all content classification labels.
     *
     * @param locale The locale for the content classification labels.
     */
    async getAll(locale) {
        const result = await this._client.callApi({
            url: 'content_classification_labels',
            query: {
                locale,
            },
        });
        return result.data.map(data => new HelixContentClassificationLabel(data));
    }
};
HelixContentClassificationLabelApi = __decorate([
    rtfm('api', 'HelixContentClassificationLabelApi')
], HelixContentClassificationLabelApi);
export { HelixContentClassificationLabelApi };
